#Acknowledge

- These shaders come from panda3d-simple pbr. https://github.com/Moguri/panda3d-simplepbr
- To make them work on headless machine with openGLES 2 graphics pipe, we convert them to gles shader language.